'use strict';

var view = require('@codemirror/view');
var language = require('@codemirror/language');
var highlight = require('@lezer/highlight');

// Using https://github.com/sdras/night-owl-vscode-theme as reference for the colors
const colors$1 = {
    foreground: "#ced4d9",
    editorBackground: "#0b253a",
    cursor: "#ffffff",
    activeLineBg: "#0116273b",
    selection: "#1a3b57",
    highlightBrackets: "#bad0f847",
    tooltipBackground: "#005498",
    selectionMatch: "#166cb5",
    panelBg: "#041c30",
    lineNumbers: "#7d8799",
    boolean: "#FF5874",
    number: "#F78C6C",
    string: "#ECC48D",
    keyword: "#C792EA",
    variables: "#D7DBE0",
    self: "#7FDBCA",
    typeColor: "#FFCB8B",
    property: "#BAEBE2",
    propertyDef: "#82AAFF",
    invalid: "#ffc4c8",
    attr: "#C5E478",
    tags: "#CAECE6",
    regexp: "#5CA7E4",
};
/// The editor theme styles.
const nightOwlTheme = view.EditorView.theme({
    "&": {
        color: colors$1.foreground,
        backgroundColor: colors$1.editorBackground,
    },
    ".cm-content": {
        caretColor: colors$1.cursor,
    },
    ".cm-cursor, .cm-dropCursor": { borderLeftColor: colors$1.cursor },
    "&.cm-focused > .cm-scroller > .cm-selectionLayer .cm-selectionBackground, .cm-selectionBackground, .cm-content ::selection": { backgroundColor: colors$1.selection },
    ".cm-panels": {
        backgroundColor: colors$1.panelBg,
        color: colors$1.foreground,
    },
    ".cm-activeLine": { backgroundColor: colors$1.activeLineBg },
    ".cm-matchingBracket, &.cm-focused .cm-nonmatchingBracket": {
        backgroundColor: colors$1.highlightBrackets,
    },
    ".cm-gutters": {
        backgroundColor: colors$1.editorBackground,
        color: colors$1.lineNumbers,
        border: "none",
    },
    ".cm-activeLineGutter": {
        backgroundColor: colors$1.activeLineBg,
        color: colors$1.foreground,
    },
    ".cm-panels.cm-panels-top": { borderBottom: "2px solid black" },
    ".cm-panels.cm-panels-bottom": { borderTop: "2px solid black" },
    ".cm-panel.cm-search button": {
        backgroundImage: "linear-gradient(#0d2f4b, #072034)",
        border: "1px solid #595959",
    },
    ".cm-searchMatch, .cm-selectionMatch": {
        backgroundColor: colors$1.selectionMatch,
        outline: `1px solid ${colors$1.tooltipBackground}`,
    },
    ".cm-searchMatch.cm-searchMatch-selected": {
        backgroundColor: "#ff01014d",
        outline: "1px solid #ff4545",
    },
    ".cm-foldPlaceholder": {
        backgroundColor: colors$1.selection,
        border: "none",
        color: colors$1.foreground,
    },
    ".cm-tooltip": {
        border: "none",
        backgroundColor: colors$1.tooltipBackground,
    },
    ".cm-tooltip .cm-tooltip-arrow:before": {
        borderTopColor: "transparent",
        borderBottomColor: "transparent",
    },
    ".cm-tooltip .cm-tooltip-arrow:after": {
        borderTopColor: colors$1.tooltipBackground,
        borderBottomColor: colors$1.tooltipBackground,
    },
    ".cm-tooltip-autocomplete": {
        "& > ul > li[aria-selected]": {
            backgroundColor: colors$1.selectionMatch,
            color: colors$1.foreground,
        },
    },
}, { dark: true });
const nightOwlHighlightStyle = language.HighlightStyle.define([
    { tag: [highlight.tags.meta, highlight.tags.comment], color: "#637777" },
    { tag: highlight.tags.number, color: colors$1.number },
    {
        tag: [highlight.tags.atom, highlight.tags.null, highlight.tags.bool, highlight.tags.special(highlight.tags.variableName)],
        color: colors$1.boolean,
    },
    {
        tag: [highlight.tags.processingInstruction, highlight.tags.string, highlight.tags.inserted, highlight.tags.special(highlight.tags.string)],
        color: colors$1.string,
    },
    {
        tag: [highlight.tags.keyword, highlight.tags.modifier, highlight.tags.operator, highlight.tags.changed],
        color: colors$1.keyword,
    },
    { tag: highlight.tags.self, color: colors$1.self },
    {
        tag: [
            highlight.tags.name,
            highlight.tags.variableName,
            highlight.tags.labelName,
            highlight.tags.character,
            highlight.tags.macroName,
            highlight.tags.deleted,
        ],
        color: colors$1.variables,
    },
    {
        tag: [highlight.tags.typeName, highlight.tags.className, highlight.tags.annotation, highlight.tags.namespace],
        color: colors$1.typeColor,
    },
    { tag: highlight.tags.propertyName, color: colors$1.property },
    {
        tag: [
            highlight.tags.macroName,
            highlight.tags.standard(highlight.tags.name),
            highlight.tags.definition(highlight.tags.propertyName),
            highlight.tags.function(highlight.tags.name),
            highlight.tags.function(highlight.tags.variableName),
            highlight.tags.function(highlight.tags.propertyName),
        ],
        color: colors$1.propertyDef,
    },
    {
        tag: [
            highlight.tags.constant(highlight.tags.variableName),
            highlight.tags.constant(highlight.tags.name),
            highlight.tags.special(highlight.tags.variableName),
        ],
        color: colors$1.propertyDef,
    },
    { tag: highlight.tags.escape, color: colors$1.number },
    { tag: highlight.tags.regexp, color: colors$1.regexp },
    { tag: [highlight.tags.link, highlight.tags.url], textDecoration: "underline" },
    { tag: highlight.tags.color, color: colors$1.self },
    { tag: highlight.tags.attributeName, color: colors$1.attr },
    { tag: highlight.tags.invalid, color: colors$1.invalid },
    { tag: highlight.tags.heading, fontWeight: "bold", color: colors$1.attr },
    { tag: highlight.tags.strong, fontWeight: "bold" },
    { tag: highlight.tags.emphasis, fontStyle: "italic" },
    { tag: highlight.tags.strikethrough, textDecoration: "line-through" },
    { tag: highlight.tags.angleBracket, color: colors$1.self },
    { tag: highlight.tags.tagName, color: colors$1.tags },
    { tag: highlight.tags.attributeValue, color: colors$1.string },
    { tag: highlight.tags.meta, color: colors$1.number },
]);
/// Extension to enable theme (both the editor theme and the highlight style).
const nightOwl = [
    nightOwlTheme,
    language.syntaxHighlighting(nightOwlHighlightStyle),
];

// Using https://github.com/sdras/night-owl-vscode-theme as reference for the colors
/// The colors used in the theme.
const colors = {
    foreground: "#797979",
    editorBackground: "#FBFBFB",
    activeLineBg: "#e7e7e77a",
    selection: "#adcff09e",
    boolean: "#BC5454",
    number: "#AA0982",
    string: "#c82521",
    keyword: "#994CC3",
    variables: "#403F53",
    self: "#0C969B",
    typeColor: "#111111",
    property: "#0C969B",
    propertyDef: "#4876D6",
    invalid: "#ffc4c8",
};
/// The editor theme styles
const nightOwlLightTheme = view.EditorView.theme({
    "&": {
        color: colors.foreground,
        backgroundColor: colors.editorBackground,
    },
    ".cm-searchMatch": {
        backgroundColor: "#72a1ff59",
        outline: "1px solid #457dff",
    },
    ".cm-searchMatch.cm-searchMatch-selected": {
        backgroundColor: "#ff01014d",
        outline: "1px solid #ff4545",
    },
    ".cm-activeLine": { backgroundColor: colors.activeLineBg },
    ".cm-selectionMatch": {
        backgroundColor: colors.selection,
        outline: "1px solid",
    },
    ".cm-gutters": {
        backgroundColor: colors.editorBackground,
        color: "#7d8799",
        border: "none",
    },
    ".cm-activeLineGutter": {
        backgroundColor: colors.activeLineBg,
        color: "#003981",
    },
});
const nightOwlLightHighlightStyle = language.HighlightStyle.define([
    { tag: [highlight.tags.meta, highlight.tags.comment], color: "#637777" },
    { tag: highlight.tags.number, color: colors.number },
    {
        tag: [highlight.tags.atom, highlight.tags.null, highlight.tags.bool, highlight.tags.special(highlight.tags.variableName)],
        color: colors.boolean,
    },
    {
        tag: [highlight.tags.processingInstruction, highlight.tags.string, highlight.tags.inserted, highlight.tags.special(highlight.tags.string)],
        color: colors.string,
    },
    {
        tag: [highlight.tags.keyword, highlight.tags.modifier, highlight.tags.operator, highlight.tags.changed],
        color: colors.keyword,
    },
    { tag: highlight.tags.self, color: colors.self },
    {
        tag: [
            highlight.tags.name,
            highlight.tags.variableName,
            highlight.tags.labelName,
            highlight.tags.character,
            highlight.tags.macroName,
            highlight.tags.deleted,
        ],
        color: colors.variables,
    },
    {
        tag: [highlight.tags.typeName, highlight.tags.className, highlight.tags.annotation, highlight.tags.namespace],
        color: colors.typeColor,
    },
    { tag: highlight.tags.propertyName, color: colors.property },
    {
        tag: [
            highlight.tags.macroName,
            highlight.tags.standard(highlight.tags.name),
            highlight.tags.definition(highlight.tags.propertyName),
            highlight.tags.function(highlight.tags.name),
            highlight.tags.function(highlight.tags.variableName),
            highlight.tags.function(highlight.tags.propertyName),
        ],
        color: colors.propertyDef,
    },
    {
        tag: [
            highlight.tags.constant(highlight.tags.variableName),
            highlight.tags.constant(highlight.tags.name),
            highlight.tags.special(highlight.tags.variableName),
        ],
        color: "#82AAFF",
    },
    { tag: highlight.tags.escape, color: "#F78C6C" },
    { tag: highlight.tags.regexp, color: "#5CA7E4" },
    { tag: [highlight.tags.link, highlight.tags.url], textDecoration: "underline" },
    { tag: highlight.tags.color, color: colors.self },
    { tag: highlight.tags.attributeName, color: colors.propertyDef },
    { tag: highlight.tags.invalid, color: colors.invalid },
    { tag: highlight.tags.heading, fontWeight: "bold", color: "#C5E478" },
    { tag: highlight.tags.strong, fontWeight: "bold" },
    { tag: highlight.tags.emphasis, fontStyle: "italic" },
    { tag: highlight.tags.strikethrough, textDecoration: "line-through" },
    { tag: highlight.tags.angleBracket, color: colors.keyword },
    { tag: highlight.tags.tagName, color: colors.keyword },
    { tag: highlight.tags.attributeValue, color: colors.string },
    { tag: highlight.tags.meta, color: colors.keyword },
]);
const nightOwlLight = [
    nightOwlLightTheme,
    language.syntaxHighlighting(nightOwlLightHighlightStyle),
];

exports.nightOwl = nightOwl;
exports.nightOwlLight = nightOwlLight;
