'use strict';

var view = require('@codemirror/view');
var language = require('@codemirror/language');
var highlight = require('@lezer/highlight');

// Using https://github.com/sdras/night-owl-vscode-theme as reference for the colors
/// The colors used in the theme.
const colors = {
    foreground: "#797979",
    editorBackground: "#FBFBFB",
    activeLineBg: "#e7e7e77a",
    selection: "#adcff09e",
    boolean: "#BC5454",
    number: "#AA0982",
    string: "#c82521",
    keyword: "#994CC3",
    variables: "#403F53",
    self: "#0C969B",
    typeColor: "#111111",
    property: "#0C969B",
    propertyDef: "#4876D6",
    invalid: "#ffc4c8",
};
/// The editor theme styles
const nightOwlLightTheme = view.EditorView.theme({
    "&": {
        color: colors.foreground,
        backgroundColor: colors.editorBackground,
    },
    ".cm-searchMatch": {
        backgroundColor: "#72a1ff59",
        outline: "1px solid #457dff",
    },
    ".cm-searchMatch.cm-searchMatch-selected": {
        backgroundColor: "#ff01014d",
        outline: "1px solid #ff4545",
    },
    ".cm-activeLine": { backgroundColor: colors.activeLineBg },
    ".cm-selectionMatch": {
        backgroundColor: colors.selection,
        outline: "1px solid",
    },
    ".cm-gutters": {
        backgroundColor: colors.editorBackground,
        color: "#7d8799",
        border: "none",
    },
    ".cm-activeLineGutter": {
        backgroundColor: colors.activeLineBg,
        color: "#003981",
    },
});
const nightOwlLightHighlightStyle = language.HighlightStyle.define([
    { tag: [highlight.tags.meta, highlight.tags.comment], color: "#637777" },
    { tag: highlight.tags.number, color: colors.number },
    {
        tag: [highlight.tags.atom, highlight.tags.null, highlight.tags.bool, highlight.tags.special(highlight.tags.variableName)],
        color: colors.boolean,
    },
    {
        tag: [highlight.tags.processingInstruction, highlight.tags.string, highlight.tags.inserted, highlight.tags.special(highlight.tags.string)],
        color: colors.string,
    },
    {
        tag: [highlight.tags.keyword, highlight.tags.modifier, highlight.tags.operator, highlight.tags.changed],
        color: colors.keyword,
    },
    { tag: highlight.tags.self, color: colors.self },
    {
        tag: [
            highlight.tags.name,
            highlight.tags.variableName,
            highlight.tags.labelName,
            highlight.tags.character,
            highlight.tags.macroName,
            highlight.tags.deleted,
        ],
        color: colors.variables,
    },
    {
        tag: [highlight.tags.typeName, highlight.tags.className, highlight.tags.annotation, highlight.tags.namespace],
        color: colors.typeColor,
    },
    { tag: highlight.tags.propertyName, color: colors.property },
    {
        tag: [
            highlight.tags.macroName,
            highlight.tags.standard(highlight.tags.name),
            highlight.tags.definition(highlight.tags.propertyName),
            highlight.tags.function(highlight.tags.name),
            highlight.tags.function(highlight.tags.variableName),
            highlight.tags.function(highlight.tags.propertyName),
        ],
        color: colors.propertyDef,
    },
    {
        tag: [
            highlight.tags.constant(highlight.tags.variableName),
            highlight.tags.constant(highlight.tags.name),
            highlight.tags.special(highlight.tags.variableName),
        ],
        color: "#82AAFF",
    },
    { tag: highlight.tags.escape, color: "#F78C6C" },
    { tag: highlight.tags.regexp, color: "#5CA7E4" },
    { tag: [highlight.tags.link, highlight.tags.url], textDecoration: "underline" },
    { tag: highlight.tags.color, color: colors.self },
    { tag: highlight.tags.attributeName, color: colors.propertyDef },
    { tag: highlight.tags.invalid, color: colors.invalid },
    { tag: highlight.tags.heading, fontWeight: "bold", color: "#C5E478" },
    { tag: highlight.tags.strong, fontWeight: "bold" },
    { tag: highlight.tags.emphasis, fontStyle: "italic" },
    { tag: highlight.tags.strikethrough, textDecoration: "line-through" },
    { tag: highlight.tags.angleBracket, color: colors.keyword },
    { tag: highlight.tags.tagName, color: colors.keyword },
    { tag: highlight.tags.attributeValue, color: colors.string },
    { tag: highlight.tags.meta, color: colors.keyword },
]);
const nightOwlLight = [
    nightOwlLightTheme,
    language.syntaxHighlighting(nightOwlLightHighlightStyle),
];

exports.colors = colors;
exports.nightOwlLight = nightOwlLight;
exports.nightOwlLightHighlightStyle = nightOwlLightHighlightStyle;
exports.nightOwlLightTheme = nightOwlLightTheme;
