import { EditorView } from '@codemirror/view';
import { HighlightStyle, syntaxHighlighting } from '@codemirror/language';
import { tags } from '@lezer/highlight';

// Using https://github.com/sdras/night-owl-vscode-theme as reference for the colors
/// The colors used in the theme.
const colors = {
    foreground: "#797979",
    editorBackground: "#FBFBFB",
    activeLineBg: "#e7e7e77a",
    selection: "#adcff09e",
    boolean: "#BC5454",
    number: "#AA0982",
    string: "#c82521",
    keyword: "#994CC3",
    variables: "#403F53",
    self: "#0C969B",
    typeColor: "#111111",
    property: "#0C969B",
    propertyDef: "#4876D6",
    invalid: "#ffc4c8",
};
/// The editor theme styles
const nightOwlLightTheme = EditorView.theme({
    "&": {
        color: colors.foreground,
        backgroundColor: colors.editorBackground,
    },
    ".cm-searchMatch": {
        backgroundColor: "#72a1ff59",
        outline: "1px solid #457dff",
    },
    ".cm-searchMatch.cm-searchMatch-selected": {
        backgroundColor: "#ff01014d",
        outline: "1px solid #ff4545",
    },
    ".cm-activeLine": { backgroundColor: colors.activeLineBg },
    ".cm-selectionMatch": {
        backgroundColor: colors.selection,
        outline: "1px solid",
    },
    ".cm-gutters": {
        backgroundColor: colors.editorBackground,
        color: "#7d8799",
        border: "none",
    },
    ".cm-activeLineGutter": {
        backgroundColor: colors.activeLineBg,
        color: "#003981",
    },
});
const nightOwlLightHighlightStyle = HighlightStyle.define([
    { tag: [tags.meta, tags.comment], color: "#637777" },
    { tag: tags.number, color: colors.number },
    {
        tag: [tags.atom, tags.null, tags.bool, tags.special(tags.variableName)],
        color: colors.boolean,
    },
    {
        tag: [tags.processingInstruction, tags.string, tags.inserted, tags.special(tags.string)],
        color: colors.string,
    },
    {
        tag: [tags.keyword, tags.modifier, tags.operator, tags.changed],
        color: colors.keyword,
    },
    { tag: tags.self, color: colors.self },
    {
        tag: [
            tags.name,
            tags.variableName,
            tags.labelName,
            tags.character,
            tags.macroName,
            tags.deleted,
        ],
        color: colors.variables,
    },
    {
        tag: [tags.typeName, tags.className, tags.annotation, tags.namespace],
        color: colors.typeColor,
    },
    { tag: tags.propertyName, color: colors.property },
    {
        tag: [
            tags.macroName,
            tags.standard(tags.name),
            tags.definition(tags.propertyName),
            tags.function(tags.name),
            tags.function(tags.variableName),
            tags.function(tags.propertyName),
        ],
        color: colors.propertyDef,
    },
    {
        tag: [
            tags.constant(tags.variableName),
            tags.constant(tags.name),
            tags.special(tags.variableName),
        ],
        color: "#82AAFF",
    },
    { tag: tags.escape, color: "#F78C6C" },
    { tag: tags.regexp, color: "#5CA7E4" },
    { tag: [tags.link, tags.url], textDecoration: "underline" },
    { tag: tags.color, color: colors.self },
    { tag: tags.attributeName, color: colors.propertyDef },
    { tag: tags.invalid, color: colors.invalid },
    { tag: tags.heading, fontWeight: "bold", color: "#C5E478" },
    { tag: tags.strong, fontWeight: "bold" },
    { tag: tags.emphasis, fontStyle: "italic" },
    { tag: tags.strikethrough, textDecoration: "line-through" },
    { tag: tags.angleBracket, color: colors.keyword },
    { tag: tags.tagName, color: colors.keyword },
    { tag: tags.attributeValue, color: colors.string },
    { tag: tags.meta, color: colors.keyword },
]);
const nightOwlLight = [
    nightOwlLightTheme,
    syntaxHighlighting(nightOwlLightHighlightStyle),
];

export { colors, nightOwlLight, nightOwlLightHighlightStyle, nightOwlLightTheme };
