import { EditorView } from '@codemirror/view';
import { HighlightStyle, syntaxHighlighting } from '@codemirror/language';
import { tags } from '@lezer/highlight';

// Using https://github.com/sdras/night-owl-vscode-theme as reference for the colors
const colors = {
    foreground: "#ced4d9",
    editorBackground: "#0b253a",
    cursor: "#ffffff",
    activeLineBg: "#0116273b",
    selection: "#1a3b57",
    highlightBrackets: "#bad0f847",
    tooltipBackground: "#005498",
    selectionMatch: "#166cb5",
    panelBg: "#041c30",
    lineNumbers: "#7d8799",
    boolean: "#FF5874",
    number: "#F78C6C",
    string: "#ECC48D",
    keyword: "#C792EA",
    variables: "#D7DBE0",
    self: "#7FDBCA",
    typeColor: "#FFCB8B",
    property: "#BAEBE2",
    propertyDef: "#82AAFF",
    invalid: "#ffc4c8",
    attr: "#C5E478",
    tags: "#CAECE6",
    regexp: "#5CA7E4",
};
/// The editor theme styles.
const nightOwlTheme = EditorView.theme({
    "&": {
        color: colors.foreground,
        backgroundColor: colors.editorBackground,
    },
    ".cm-content": {
        caretColor: colors.cursor,
    },
    ".cm-cursor, .cm-dropCursor": { borderLeftColor: colors.cursor },
    "&.cm-focused > .cm-scroller > .cm-selectionLayer .cm-selectionBackground, .cm-selectionBackground, .cm-content ::selection": { backgroundColor: colors.selection },
    ".cm-panels": {
        backgroundColor: colors.panelBg,
        color: colors.foreground,
    },
    ".cm-activeLine": { backgroundColor: colors.activeLineBg },
    ".cm-matchingBracket, &.cm-focused .cm-nonmatchingBracket": {
        backgroundColor: colors.highlightBrackets,
    },
    ".cm-gutters": {
        backgroundColor: colors.editorBackground,
        color: colors.lineNumbers,
        border: "none",
    },
    ".cm-activeLineGutter": {
        backgroundColor: colors.activeLineBg,
        color: colors.foreground,
    },
    ".cm-panels.cm-panels-top": { borderBottom: "2px solid black" },
    ".cm-panels.cm-panels-bottom": { borderTop: "2px solid black" },
    ".cm-panel.cm-search button": {
        backgroundImage: "linear-gradient(#0d2f4b, #072034)",
        border: "1px solid #595959",
    },
    ".cm-searchMatch, .cm-selectionMatch": {
        backgroundColor: colors.selectionMatch,
        outline: `1px solid ${colors.tooltipBackground}`,
    },
    ".cm-searchMatch.cm-searchMatch-selected": {
        backgroundColor: "#ff01014d",
        outline: "1px solid #ff4545",
    },
    ".cm-foldPlaceholder": {
        backgroundColor: colors.selection,
        border: "none",
        color: colors.foreground,
    },
    ".cm-tooltip": {
        border: "none",
        backgroundColor: colors.tooltipBackground,
    },
    ".cm-tooltip .cm-tooltip-arrow:before": {
        borderTopColor: "transparent",
        borderBottomColor: "transparent",
    },
    ".cm-tooltip .cm-tooltip-arrow:after": {
        borderTopColor: colors.tooltipBackground,
        borderBottomColor: colors.tooltipBackground,
    },
    ".cm-tooltip-autocomplete": {
        "& > ul > li[aria-selected]": {
            backgroundColor: colors.selectionMatch,
            color: colors.foreground,
        },
    },
}, { dark: true });
const nightOwlHighlightStyle = HighlightStyle.define([
    { tag: [tags.meta, tags.comment], color: "#637777" },
    { tag: tags.number, color: colors.number },
    {
        tag: [tags.atom, tags.null, tags.bool, tags.special(tags.variableName)],
        color: colors.boolean,
    },
    {
        tag: [tags.processingInstruction, tags.string, tags.inserted, tags.special(tags.string)],
        color: colors.string,
    },
    {
        tag: [tags.keyword, tags.modifier, tags.operator, tags.changed],
        color: colors.keyword,
    },
    { tag: tags.self, color: colors.self },
    {
        tag: [
            tags.name,
            tags.variableName,
            tags.labelName,
            tags.character,
            tags.macroName,
            tags.deleted,
        ],
        color: colors.variables,
    },
    {
        tag: [tags.typeName, tags.className, tags.annotation, tags.namespace],
        color: colors.typeColor,
    },
    { tag: tags.propertyName, color: colors.property },
    {
        tag: [
            tags.macroName,
            tags.standard(tags.name),
            tags.definition(tags.propertyName),
            tags.function(tags.name),
            tags.function(tags.variableName),
            tags.function(tags.propertyName),
        ],
        color: colors.propertyDef,
    },
    {
        tag: [
            tags.constant(tags.variableName),
            tags.constant(tags.name),
            tags.special(tags.variableName),
        ],
        color: colors.propertyDef,
    },
    { tag: tags.escape, color: colors.number },
    { tag: tags.regexp, color: colors.regexp },
    { tag: [tags.link, tags.url], textDecoration: "underline" },
    { tag: tags.color, color: colors.self },
    { tag: tags.attributeName, color: colors.attr },
    { tag: tags.invalid, color: colors.invalid },
    { tag: tags.heading, fontWeight: "bold", color: colors.attr },
    { tag: tags.strong, fontWeight: "bold" },
    { tag: tags.emphasis, fontStyle: "italic" },
    { tag: tags.strikethrough, textDecoration: "line-through" },
    { tag: tags.angleBracket, color: colors.self },
    { tag: tags.tagName, color: colors.tags },
    { tag: tags.attributeValue, color: colors.string },
    { tag: tags.meta, color: colors.number },
]);
/// Extension to enable theme (both the editor theme and the highlight style).
const nightOwl = [
    nightOwlTheme,
    syntaxHighlighting(nightOwlHighlightStyle),
];

export { colors, nightOwl, nightOwlHighlightStyle, nightOwlTheme };
